PhoenixMicro.Outbox.Message (PhoenixMicro v1.0.0)

Copy Markdown View Source

Ecto schema for the outbox_messages table.

Only available when ecto and ecto_sql are in your application's deps. Add them to use the transactional outbox feature:

{:ecto_sql, "~> 3.11"}
{:postgrex, ">= 0.0.0"}

You can replace this schema by setting:

config :phoenix_micro, outbox: [schema: MyApp.OutboxMessage]

Summary

Functions

Returns the Ecto schema source table name. Used by the Relay when building queries.

Returns true when Ecto is available in the host application.

Functions

__schema__(atom)

@spec __schema__(:source) :: String.t()

Returns the Ecto schema source table name. Used by the Relay when building queries.

ecto_available?()

@spec ecto_available?() :: boolean()

Returns true when Ecto is available in the host application.