Behaviour for pluggable message serialization.
The serializer is responsible for encoding PhoenixMicro.Message payloads
to binary when publishing, and decoding binary back to terms when consuming.
Behaviour for pluggable message serialization.
The serializer is responsible for encoding PhoenixMicro.Message payloads
to binary when publishing, and decoding binary back to terms when consuming.