Distributed tracing middleware. Propagates trace context from message headers and creates a span for each processed message.
Designed to work with :opentelemetry if available, but degrades gracefully
to a no-op if OTel is not in the application.
Distributed tracing middleware. Propagates trace context from message headers and creates a span for each processed message.
Designed to work with :opentelemetry if available, but degrades gracefully
to a no-op if OTel is not in the application.